@@ -1,12 +1,6 @@
-#' BioStatR
-#' 
-#' Motivation: Package compagnon du livre Initiation à la statistique avec R.
-#' Il contient les codes des chapitres du livre ainsi que les solutions des
-#' exercices mais aussi d'autres compléments à découvrir.
-#' 
-#' 
-#' @name BioStatR
-#' @docType package
+#' @keywords internal
+#' @aliases BioStatR-package BioStatR NULL
+#'
 #' @references F. Bertrand, M. Maumy-Bertrand, Initiation à la Statistique avec
 #' R, 4ème édition, ISBN:9782100847945, Dunod, Paris, 2023
 #' @references \emph{Initiation à la Statistique avec R}, Frédéric Bertrand, 
@@ -14,15 +8,14 @@
 #' \url{https://www.dunod.com/sciences-techniques/initiation-statistique-avec-r-cours-exemples-exercices-et-problemes-corriges-1},
 #' \url{https://github.com/fbertran/BioStatR/} et
 #' \url{https://fbertran.github.io/BioStatR/}
-#' 
+#'
+"_PACKAGE"
+
 #' @importFrom grDevices colorRampPalette gray
 #' @importFrom graphics hist par persp rect
 #' @importFrom stats as.formula lm qchisq qf qnorm quantile sd
 #' @import ggplot2
 #' 
-#' @examples
-#' set.seed(314)
-#' 
 NULL
 
 
