@@ -7,9 +7,9 @@
 #' @param x Un vecteur numérique
 #' @param \dots Des arguments à transmettre à la fonction qui créé les
 #' histogrammes
-#' @author Frédéric Bertrand\cr \email{frederic.bertrand@@utt.fr}\cr
+#' @author Frédéric Bertrand\cr \email{frederic.bertrand@@lecnam.net}\cr
 #' \url{https://fbertran.github.io/homepage/}\cr 
-#' Maumy-Bertrand\cr \email{myriam.maumy@@utt.fr}\cr
+#' Maumy-Bertrand\cr \email{myriam.maumy@@ehesp.fr}\cr
 #' \url{https://www.ehesp.fr/annuaire/enseignement-recherche/myriam-maumy/}
 #' @seealso \code{\link{pairs}}, \code{\link{hist}}
 #' @references F. Bertrand, M. Maumy-Bertrand, Initiation à la Statistique avec
@@ -23,10 +23,11 @@
 #' @export panel.hist
 panel.hist <- function(x, ...)
 {
-    usr <- par("usr"); on.exit(par(usr))
+    usr <- par("usr"); on.exit(par("usr"))
     par(usr = c(usr[1:2], 0, 1.5) )
     h <- hist(x, plot = FALSE)
     breaks <- h$breaks; nB <- length(breaks)
     y <- h$counts; y <- y/max(y)
-    rect(breaks[-nB], 0, breaks[-1], y, col="cyan", ...)
+    rect(xleft=breaks[-nB], ybottom=0, xright=breaks[-1], 
+         ytop=y, col="cyan", ...)
 }
